Step

Struct Step 

pub struct Step<L, R> {
    pub indices: Indices,
    pub result: Option<ConvergeTo<L, R>>,
}
The output of one bisection step.

The output consists of two parts:

  • indices: The indices of the converged view
  • result: The output of the convergence function

The indices can be used to progress the bisection. The outputted indices are the indices of the next step.

The result is Option::Some when the convergence method can progress further, and Option::None when, for the given input indices, the bisector was already in a converged state. This property can be used to stop the bisection when used in a loop; i.e., you can loop while let Some(result) = step.result.

The result, when Option::Some, also contains the output of the convergence as ConvergeTo::Left(left) or ConvergeTo::Right(right), where left and right are the left and right convergence outputs respectively.

Fields

indices: Indicesresult: Option<ConvergeTo<L, R>>